@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import hashlib
-import json
+import ujson as json
 
 from cassandra import query
 from oslo_log import log
